<?php

/**
 * Class Strong_Testimonials_Pro_Updater
 *
 * @since 2.28.0
 */
class Strong_Testimonials_Pro_Updater {

	/**
	 * Strong_Testimonials_Updater constructor.
	 */

	private $main_item_id = 13054; // the download id of this addon

	public function __construct() {
		add_action( 'admin_init', array( $this, 'plugin_updater' ), 0 );
	}

	public function plugin_updater() {

		if ( ! class_exists( 'Strong_Testimonials_Base_Addon_Updater' ) ) {
			// load our custom updater
			require_once WPMTST_PRO_PATH . 'includes/updater/class-strong-testimonials-base-addon-updater.php';
		}

		// retrieve our license key from the DB
		$license_key = trim( get_option( 'strong_testimonials_license_key' ) );

		// setup the updater
		$st_updater = new Strong_Testimonials_Base_Addon_Updater(
			WPMTST_STORE_URL,
			WPMTST_PRO_FILE,
			array(
				'version' => WPMTST_PRO_VERSION,          // current version number
				'license' => $license_key,               // license key (used get_option above to retrieve from DB)
				'item_id' => $this->main_item_id,       // ID of the product
				'author'  => 'MachoThemes',            // author of this plugin
				'beta'    => false,
			)
		);

		/**
		 * Action hook to allow other plugins to hook into the updater.
		 *
		 * @param string $license_key The license key.
		 * @param string $store_url The store URL.
		 */
		do_action( 'wpmtst_pro_updater', $license_key, WPMTST_STORE_URL );
	}

	/**
	 * Plugin activation and update.
	 *
	 * ---------
	 * REMEMBER!
	 * ---------
	 * If you are changing the value of a default field property,
	 * then you need to unset that value in the current field
	 * before merging in the new default values.
	 *
	 * For example, when changing a rating field property from
	 * disabled (0) to enabled (1) in order for the property to
	 * be displayed in the form editor.
	 */
	public static function update() {
		if ( get_transient( 'wpmtst_update_in_progress' ) ) {
			return;
		}

		set_transient( 'wpmtst_update_in_progress', 1, 10 );

		update_option( 'wpmtst_style_options', self::update_style_options() );

				/**
		 * Update the plugin version.
		 */
		update_option( 'wpmtst_pro_plugin_version', WPMTST_PRO_VERSION );

		delete_transient( 'wpmtst_update_in_progress' );
	}

	/**
	 * Form options.
	 *
	 * @return array
	 */
	public static function update_style_options() {
		if ( isset( $options['template'] ) ) {
			$options = get_option( 'wpmtst_style_options' );
		} else {
			$options = Strong_Testimonials_Pro_Defaults::get_style_options();
		}
			return $options;
	}
}

new Strong_Testimonials_Pro_Updater();
