<?php
/**
 * Class Strong_Testimonials_Settings_Single_Testimonial
 */
class Strong_Testimonials_Settings_Single_Testimonial {

	const TAB_NAME = 'single_testiomonial_template';

	const OPTION_NAME = 'wpmtst_style_options';

	const GROUP_NAME = 'wpmtst-style-group';

		const DEFAULT_TAB = 'general';

	/**
	 * Strong_Testimonials_Settings_Single_Testimonial constructor.
	 */
	public function __construct() {}

	/**
	 * Initialize.
	 */
	public static function init() {
		self::add_actions();
	}

	/**
	 * Add actions and filters.
	 */
	public static function add_actions() {
		add_action( 'wpmtst_register_settings', array( __CLASS__, 'register_settings' ) );
		add_action( 'wpmtst_settings_tabs', array( __CLASS__, 'register_tab' ), 5, 2 );
		add_filter( 'wpmtst_settings_callbacks', array( __CLASS__, 'register_settings_page' ) );
		add_action( 'wpmtst_settings_submit_row', array( __CLASS__, 'submit_row' ) );
	}

	/**
	 * Register settings tab.
	 *
	 * @param $active_tab
	 * @param $url
	 */
	public static function register_tab( $active_tab, $url ) {
		printf(
			'<a href="%s" class="nav-tab %s">%s</a>',
			esc_url( add_query_arg( 'tab', self::TAB_NAME, $url ) ),
			esc_attr( self::TAB_NAME === $active_tab ? 'nav-tab-active' : '' ),
			_x( 'Single Testimonial Template', 'adjective', 'strong-testimonials' )
		);
	}

	/**
	 * Register settings.
	 */
	public static function register_settings() {
		register_setting( self::GROUP_NAME, self::OPTION_NAME, array( __CLASS__, 'sanitize_options' ) );
	}

	/**
	 * Register settings page.
	 *
	 * @param $pages
	 *
	 * @return mixed
	 */
	public static function register_settings_page( $pages ) {
		$pages[ self::TAB_NAME ] = array( __CLASS__, 'settings_page' );
		return $pages;
	}

	/**
	 * Print settings page.
	 */
	public static function settings_page() {
		settings_fields( self::GROUP_NAME );
				wp_enqueue_style( 'wpmtst-admin-views-style' );
				wp_enqueue_script( 'wpmtst-admin-views-script' );
				$templates = WPMST()->templates->get_templates( 'display' );
				// Get list of image sizes
				$image_sizes = wpmtst_get_image_sizes();
				include WPMTST_PRO_ADMIN . 'settings/partials/views/group-fields.php';
		include WPMTST_PRO_ADMIN . 'settings/partials/views/group-style.php';
	}

	/**
	 * Sanitize settings.
	 *
	 * @param $input
	 *
	 * @return array
	 */
	public static function sanitize_options( $input ) {
			$data['template'] = sanitize_text_field( $input['template'] );
		foreach ( $input['template_settings'] as $template => $settings ) {
			foreach ( $settings as $key => $setting ) {
					// This does not work for checkboxes yet.
					$data['template_settings'][ $template ][ $key ] = apply_filters( 'wpmtst_sanitize_view_template_setting', sanitize_text_field( $setting ), $key );
			}
		}
			//Title
			$data['title'] = wpmtst_sanitize_checkbox( $input, 'title' );

			// Thumbnail
			$data['thumbnail']        = wpmtst_sanitize_checkbox( $input, 'thumbnail' );
			$data['thumbnail_size']   = sanitize_text_field( $input['thumbnail_size'] );
			$data['thumbnail_width']  = max( 0, sanitize_text_field( $input['thumbnail_width'] ) );
			$data['thumbnail_height'] = max( 0, sanitize_text_field( $input['thumbnail_height'] ) );

			// Client section
		if ( isset( $input['client_section'] ) ) {
			$data['client_section'] = wpmtst_sanitize_view_client_section( $input['client_section'] );
		} else {
			$data['client_section'] = null;
		}

			// Social Media
		if ( isset( $input['social_media'] ) ) {
			$data['social_media']['status']    = wpmtst_sanitize_checkbox( $input['social_media'], 'status' );
			$data['social_media']['facebook']  = wpmtst_sanitize_checkbox( $input['social_media'], 'facebook' );
			$data['social_media']['twitter']   = wpmtst_sanitize_checkbox( $input['social_media'], 'twitter' );
			$data['social_media']['pinterest'] = wpmtst_sanitize_checkbox( $input['social_media'], 'pinterest' );
			$data['social_media']['linkedin']  = wpmtst_sanitize_checkbox( $input['social_media'], 'linkedin' );
		}

			// Background
			$data['background'] = wpmtst_get_background_defaults();
		if ( ! isset( $input['background']['type'] ) ) {
				$data['background']['type'] = '';
		} else {
				$data['background']['type'] = sanitize_text_field( $input['background']['type'] );
		}
			$data['background']['color']     = sanitize_hex_color( $input['background']['color'] );
			$data['background']['gradient1'] = sanitize_hex_color( $input['background']['gradient1'] );
			$data['background']['gradient2'] = sanitize_hex_color( $input['background']['gradient2'] );
			$data['background']['preset']    = sanitize_text_field( $input['background']['preset'] );

			// Font color
		if ( ! isset( $input['font-color']['type'] ) ) {
				$data['font-color']['type'] = '';
		} else {
				$data['font-color']['type'] = sanitize_text_field( $input['font-color']['type'] );
		}
			$data['font-color']['color'] = sanitize_hex_color( $input['font-color']['color'] );

			$data['gravatar']    = sanitize_text_field( $input['gravatar'] );
			$data['saved_image'] = sanitize_text_field( $input['saved_image'] );

			$data['lightbox'] = wpmtst_sanitize_checkbox( $input, 'lightbox' );

			$data['lightbox_class'] = sanitize_text_field( $input['lightbox_class'] );

			return $data;
	}

	public static function submit_row() {
		if ( 'single_testiomonial_template' === self::get_tab() ) {
			submit_button( '', 'primary', 'submit-form', false );
		}
	}

	private static function get_tab() {
		return ( isset( $_GET['tab'] ) && $_GET['tab'] ) ? $_GET['tab'] : self::DEFAULT_TAB;
	}
}

Strong_Testimonials_Settings_Single_Testimonial::init();
