( function ( $ ) {
	'use strict';

	function stInstallAddon( $url ) {
		// Process the Ajax to perform the activation.
		const opts = {
			// eslint-disable-next-line no-undef
			url: ajaxurl,
			type: 'post',
			async: true,
			cache: false,
			dataType: 'json',
			data: {
				action: 'wpmtst-install-addons',
				// eslint-disable-next-line no-undef
				nonce: wpmtstPRO.install_nonce,
				plugin: $url,
			},
			success( response ) {
				// If there is a WP Error instance, output it here and quit the script.
				if ( response.error ) {
					console.log( response.error );
					return;
				}

				// If we need more credentials, output the form sent back to us.
				if ( response.form ) {
					// Display the form to gather the users credentials.
					$( '.st-addons-error' ).html( response.form );

					$( '.st-addons-error' ).on(
						'click',
						'#upgrade',
						function ( e ) {
							// Prevent the default action, let the user know we are attempting to install again and go with it.
							e.preventDefault();

							// Now let's make another Ajax request once the user has submitted their credentials.
							const hostname = $( this )
								.parent()
								.parent()
								.find( '#hostname' )
								.val();
							const username = $( this )
								.parent()
								.parent()
								.find( '#username' )
								.val();
							const password = $( this )
								.parent()
								.parent()
								.find( '#password' )
								.val();
							$( '.st-addons-error' ).html( '' );
							const credOpts = {
								// eslint-disable-next-line no-undef
								url: ajaxurl,
								type: 'post',
								async: true,
								cache: false,
								dataType: 'json',
								data: {
									action: 'wpmtst-install-addons',
									// eslint-disable-next-line no-undef
									nonce: wpmtstPRO.install_nonce,
									plugin: $url,
									hostname,
									username,
									password,
								},
								success( secResponse ) {
									// If there is a WP Error instance, output it here and quit the script.
									if ( secResponse.error ) {
										console.log( secResponse.error );
										return;
									}

									if ( secResponse.form ) {
										$( '.st-addons-error' ).html(
											'<div class="notice notice-error"><p>' +
												// eslint-disable-next-line no-undef
												wpmtstPRO.connect_error +
												'</p></div>'
										);
										return;
									}

									// The Ajax request was successful, so let's activate the addon.
									if ( secResponse.activate_url ) {
										stActivateAddon(
											secResponse.activate_url
										);
									}
								},
								error( xhr, textStatus, el ) {
									console.log( xhr );
									console.log( textStatus );
									console.log( el );
								},
							};
							$.ajax( credOpts );
						}
					);

					// No need to move further if we need to enter our creds.
					return;
				}

				// The Ajax request was successful, so let's update the output.
				if ( response.activate_url ) {
					stActivateAddon( response.activate_url );
				}
			},
			error( xhr, textStatus, e ) {
				console.log( xhr );
				console.log( textStatus );
				console.log( e );
			},
		};

		$.ajax( opts );
	}

	function stActivateAddon( url ) {
		jQuery.ajax( {
			type: 'GET',
			dataType: 'html',
			url,
			success() {
				location.reload();
			},
		} );
	}

	function stDeactivateAddon( url ) {
		jQuery.ajax( {
			type: 'GET',
			dataType: 'html',
			url,
			success() {
				location.reload();
			},
		} );
	}

	$( document ).ready( function () {
		// Re-enable install button if user clicks on it, needs creds but tries to install another addon instead.
		$( '.wpmtst-addons-container' ).on(
			'click',
			'.wpmtst-addon-action',
			function ( e ) {
				const url = $( this ).attr( 'href' ),
					action = $( this ).data( 'action' );

				e.preventDefault();
				$( this ).addClass( 'updating-message' );

				if ( 'install' === action ) {
					stInstallAddon( url );
				} else if ( 'activate' === action ) {
					stActivateAddon( url );
				} else if ( 'deactivate' === action ) {
					stDeactivateAddon( url );
				}
			}
		);
	} );
} )( jQuery );
