<?php
/**
 * Class Strong_Testimonials_Pro
 */
class Strong_Testimonials_Pro {


	public $admin;
	public $defaults;

	public function __construct() {
		$this->setup_constants();

		$this->includes();

		$this->add_actions();

		$this->admin    = new Strong_Testimonials_Pro_Admin();
		$this->defaults = new Strong_Testimonials_Pro_Defaults();
	}

	/**
	 * Our constants.
	 */
	private function setup_constants() {
		defined( 'WPMTST_PRO' ) || define( 'WPMTST_PRO', 'strong-testimonials-pro' );
		defined( 'WPMTST_PRO_URL' ) || define( 'WPMTST_PRO_URL', plugin_dir_url( __FILE__ ) );
		defined( 'WPMTST_PRO_PATH' ) || define( 'WPMTST_PRO_PATH', plugin_dir_path( __FILE__ ) );
		defined( 'WPMTST_PRO_ADMIN' ) || define( 'WPMTST_PRO_ADMIN', WPMTST_PRO_PATH . 'admin/' );
		define( 'WPMTST_PRO_FILE', __FILE__ );
	}

	/**
	 * Our includes.
	 */
	private function includes() {
		// License Tab
		require_once WPMTST_PRO_PATH . 'includes/admin/class-strong-testimonials-pro-license.php';
		// Addons page
		require_once WPMTST_PRO_PATH . 'includes/admin/class-strong-testimonials-pro-addons.php';
		// The license activator
		require_once WPMTST_PRO_PATH . 'includes/admin/class-strong-testimonials-pro-master-license-activator.php';

		require_once WPMTST_PRO_PATH . 'includes/class-strong-testimonials-pro-admin.php';
		require_once WPMTST_PRO_ADMIN . 'class-strong-testimonials-pro-defaults.php';
		require_once WPMTST_PRO_ADMIN . 'class-strong-testimonials-pro-updater.php';
		//License
		require_once WPMTST_PRO_PATH . 'includes/class-strong-testimonials-license-activator.php';
		require_once WPMTST_PRO_PATH . 'includes/class-strong-testimonials-settings-license.php';
	}

	/**
	 * Add actions and filters.
	 */
	private function add_actions() {

		add_filter( 'plugin_action_links', array( $this, 'plugin_action_links' ), 10, 2 );
		add_filter( 'the_content', array( $this, 'render_view_in_content' ) );
		// Before admin_init where the EDD Updater needs the add-on version number

		// License checker initiation
			// Need to put store_url like this because it doesn't know who the constant is.
			$args = array(
				'plugin_slug'     => 'strong-testimonials',
				'plugin_nicename' => 'Strong Testimonials',
				'store_url'       => 'https://strongtestimonials.com',
				'item_id'         => 724,
				'license'         => 'strong_testimonials_license_key',
				'license_status'  => 'strong_testimonials_license_status',
				'plugin_file'     => __FILE__,
				'addons_prefix'   => 'strong-testimonials-',
			);

			require_once __DIR__ . '/includes/submodules/license-checker/class-wpchill-license-checker.php';
			$wpchill_license_checker = Wpchill_License_Checker::get_instance( 'strong-testimonials', $args );
			if ( is_admin() ) {
				// Check if we need to add lite vs pro page
				$license = get_option( 'strong_testimonials_license_key' );
				$status  = get_option( 'strong_testimonials_license_status', false );
				if ( '' === $license || false === $status || ! isset( $status->license ) || 'valid' !== $status->license ) {
					if ( class_exists( 'Strong_Testimonials_Lite_Vs_PRO_Page' ) ) {
						new Strong_Testimonials_Lite_Vs_PRO_Page();
					}
				}
			}
	}

	/**
	 * Return plugin data.
	 */
	public static function get_plugin_info() {
		return get_file_data(
			__FILE__,
			array(
				'name'    => 'Plugin Name',
				'version' => 'Version',
			)
		);
	}


	/**
	 * Plugin action links.
	 *
	 * @param $links
	 * @param $file
	 *
	 * @return mixed
	 */
	public function plugin_action_links( $links, $file ) {
		if ( plugin_basename( __FILE__ ) === $file ) {
			$url           = 'edit.php?post_type=wpm-testimonial&page=testimonial-settings&tab=licenses';
			$settings_link = sprintf( '<a href="%s">%s</a>', admin_url( $url ), esc_html__( 'License', 'strong-testimonials-pro' ) );
			array_push( $links, $settings_link );
		}

		return $links;
	}

	public function render_view_in_content( $content ) {
		if ( is_singular( 'wpm-testimonial' ) ) {
			global $post;
			$options = get_option( 'wpmtst_style_options' );
			$fields  = wpmtst_find_single_template_view();
			$atts    = $this->defaults->get_default_view();

			$atts['id']                = $post->ID;
			$atts['template']          = isset( $options['template'] ) ? $options['template'] : 'default';
			$atts['template_settings'] = isset( $options['template_settings'] ) ? $options['template_settings'] : array();
			$atts['background']        = isset( $options['background'] ) ? $options['background'] : array(
				'color'     => '',
				'type'      => '',
				'preset'    => '',
				'gradient1' => '',
				'gradient2' => '',
			);
			$atts['font-color']        = isset( $options['font-color'] ) ? $options['font-color'] : array(
				'color' => '',
				'type'  => '',
			);
			$atts['client_section']    = isset( $options['client_section'] ) ? $options['client_section'] : array();
			$atts['content']           = 'entire';
			$atts['thumbnail']         = isset( $options['thumbnail'] ) ? $options['thumbnail'] : true;
			$atts['thumbnail_size']    = isset( $options['thumbnail_size'] ) ? $options['thumbnail_size'] : 'thumbnail';
			$atts['thumbnail_width']   = isset( $options['thumbnail_width'] ) ? $options['thumbnail_width'] : 0;
			$atts['thumbnail_height']  = isset( $options['thumbnail_height'] ) ? $options['thumbnail_height'] : 0;
			$atts['gravatar']          = isset( $options['gravatar'] ) ? $options['gravatar'] : 'no';
			$atts['default_image']     = isset( $options['saved_image'] ) ? $options['saved_image'] : '';
			$atts['lightbox']          = isset( $options['lightbox'] ) ? $options['lightbox'] : '';
			$atts['lightbox_class']    = isset( $options['lightbox_class'] ) ? $options['lightbox_class'] : '';

			if ( $options['title'] ) {
				$atts['title'] = $options['title'];
			} else {
				$atts['title'] = 'hidden';
			}

			$view = new Strong_View_Display( $atts );
			$view->build();
			$content = $view->output();

			$social = '';
			if ( isset( $options['social_media'] ) && $options['social_media']['status'] ) {
				wp_enqueue_style( 'wpmtst-social-media', WPMTST_PRO_URL . 'assets/css/social-media.css' );
				$social .= '<ul class="social-media">';
				$social .= $this->generate_social_icons( $options['social_media'] );
				$social .= '</ul>';
			}
			$content .= $social;
		}

		return $content;
	}

	private function generate_social_icons( $platforms ) {
		$url    = get_permalink();
		$title  = get_the_title();
		$output = '';
		unset( $platforms['status'] );
		foreach ( $platforms as $platform => $status ) {
			if ( $status ) {
				$output    .= '<li class="' . $platform . ' social-icon">';
				$share_icon = '<img class="platform-icon" src ="' . WPMTST_PRO_URL . '/assets/img/' . $platform . '.png" />';
				switch ( $platform ) {
					case 'facebook':
						$share_url  = 'https://www.facebook.com/sharer/sharer.php?u=' . $url . '&t=' . $title;
						$share_text = __( 'Share on Facebook', 'strong-testimonials-pro' );
						break;
					case 'twitter':
						$share_url  = 'http://www.twitter.com/intent/tweet?url=' . $url . '&text=' . $title;
						$share_text = __( 'Share on Twitter', 'strong-testimonials-pro' );
						break;
					case 'pinterest':
						$share_url  = 'http://pinterest.com/pin/create/button/?url=' . $url . '&text=' . $title;
						$share_text = __( 'Share on Pinterest', 'strong-testimonials-pro' );
						break;
					case 'linkedin':
						$share_url  = 'https://www.linkedin.com/sharing/share-offsite/?url=' . $url;
						$share_text = __( 'Share on LinkedIn', 'strong-testimonials-pro' );
						break;
				}
				$output .= '<a href="' . $share_url . '" onclick="javascript:window.open(this.href, \'\', \'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=300,width=600\');return false;" target="_blank" title="' . $share_text . '">' . $share_icon . '</a></li>';
			}
		}
		return $output;
	}
}
