<?php
// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
/**
 * Class Strong_Testimonials_Pro_Addons
 *
 * @since 1.1.0
 */
class Strong_Testimonials_Pro_License {

	/**
	 * Instance.
	 *
	 * @var null
	 * @since 1.1.0
	 */
	public static $instance = null;

	/**
	 * Addons.
	 *
	 * @var array
	 * @since 1.1.0
	 */
	private $addons = array();

	/**
	 * Strong_Testimonials_Pro_License constructor.
	 *
	 * @since 1.1.0
	 */
	private function __construct() {
		add_filter( 'wpmtst_settings_callbacks', array( $this, 'register_settings_page' ), 20 );
		add_filter( 'wpmtst_license_tab', array( $this, 'license_tab_name' ), 15, 3 );
	}

	/**
	 * Get instance.
	 *
	 * @return Strong_Testimonials_Pro_License|null
	 * @since 1.1.0
	 */
	public static function get_instance() {
		if ( ! isset( self::$instance ) && ! ( self::$instance instanceof Strong_Testimonials_Pro_License ) ) {
			self::$instance = new Strong_Testimonials_Pro_License();
		}

		return self::$instance;
	}

	/**
	 * Register settings page.
	 *
	 * @param $pages
	 *
	 * @return mixed
	 *
	 * @since 1.1.0
	 */
	public function register_settings_page( $pages ) {
		$pages['license'] = array( $this, 'render_license' );

		return $pages;
	}

	/**
	 * Render the license field.
	 *
	 * @return void
	 *
	 * @since 1.1.0
	 */
	public function render_license() {

		$license    = get_option( 'strong_testimonials_license_key' );
		$email      = get_option( 'strong_testimonials_email' );
		$status     = get_option( 'strong_testimonials_license_status', false );
		$alt_server = get_option( 'strong_testimonials_alt_server', false );
		$messages   = array(
			'no-license'       => esc_html__( 'Enter your license key', 'strong-testimonials-pro' ),
			'activate-license' => esc_html__( 'Activate your license key', 'strong-testimonials-pro' ),
			// Translators: %s is the date until the license is active.
			'all-good'         => __( 'Your license is active until <strong>%s</strong>', 'strong-testimonials-pro' ),
			'lifetime'         => __( 'You have a lifetime license.', 'strong-testimonials-pro' ),
			'expired'          => esc_html__( 'Your license has expired', 'strong-testimonials-pro' ),
		);

		if ( '' === $license ) {
			//$license_message = $messages['no-license'];
			$license_message = '';
		} elseif ( '' !== $license && false === $status ) {
			//$license_message = $messages['activate-license'];
			$license_message = '';
		} elseif ( 'expired' === $status->license ) {
			$license_message = $messages['expired'];
		} elseif ( '' !== $license && false !== $status && isset( $status->license ) && 'valid' === $status->license ) {
			$date_format = get_option( 'date_format' );

			if ( 'lifetime' === $status->expires ) {
				$license_message = $messages['lifetime'];
			} else {
				$license_expire = date( $date_format, strtotime( $status->expires ) ); // phpcs:ignore WordPress.DateTime.RestrictedFunctions.date_date
				$curr_time      = time();
				// weeks till expiration
				$weeks = (int) ( ( strtotime( $status->expires ) - $curr_time ) / ( 7 * 24 * 60 * 60 ) );

				// set license status based on colors
				if ( 4 >= $weeks ) {
					$l_stat = 'red';
				} else {
					$l_stat = 'green';
				}

				$license_message = sprintf( '<p class="%s">' . $messages['all-good'] . '</p>', $l_stat, $license_expire );

				if ( 'green' !== $l_stat ) {
					// translators: %s is the number of weeks until the license will expire.
					$license_message .= sprintf( __( 'You have %s week(s) untill your license will expire.', 'strong-testimonials-pro' ), $weeks );
				}
			}
		}
		?>

		<h2><?php esc_html_e( 'License', 'strong-testimonials-pro' ); ?></h2>
		<?php do_action( 'wpmtst_license_errors' ); ?>
			<?php
			$valid_license = false;
			if ( false !== $license && $status && 'valid' === $status->license ) {
				$valid_license = true;
			}
			?>
		<table class="form-table wpmtst_license_table" cellpadding="0" cellspacing="0">

			<tr valign="top">
				<th scope="row">
					<?php esc_html_e( 'Email Address', 'strong-testimonials-pro' ); ?>
				</th>
				<td>
					<fieldset>

							<input type="email" id="strong_testimonials_email" name="strong_testimonials_email" value="<?php echo esc_attr( $email ); ?>">
						<p class="description"><?php esc_html_e( 'The email address used for license acquisition.', 'strong-testimonials-pro' ); ?></p>
					</fieldset>
				</td>
			</tr>
			<tr valign="top">
				<th scope="row">
					<?php esc_html_e( 'License Key', 'strong-testimonials-pro' ); ?>
				</th>
				<td>
					<fieldset>

						<input type="password" id="strong_testimonials_license_key" name="strong_testimonials_license_key" value="<?php echo esc_attr( $license ); ?>">  <a href="#" target="_blank" id="st-forgot-license" data-nonce="<?php echo esc_attr( wp_create_nonce( 'strong_testimonials_license_nonce' ) ); ?>"><?php esc_html_e( 'Forgot your license?', 'strong-testimonials-pro' ); ?></a><br>
						<p class="description"><?php echo ! empty( $license_message ) ? wp_kses_post( $license_message ) : ''; ?></p>

						<input type="hidden" value="<?php echo esc_attr( wp_create_nonce( 'strong_testimonials_license_nonce' ) ); ?>"/>
						
						<label class="description strong-testimonials-license-label" for="strong_testimonials_license_key"></label>
				</fieldset>
				</td>
			</tr>
			<tr valign="top">
				<th scope="row">
					<?php esc_html_e( 'Use Alternative Server', 'strong-testimonials-pro' ); ?>
				</th>
				<td>
					<fieldset>
						<div class="wpmtst-toggle">
							<input class="wpmtst-toggle__input" type="checkbox"
								data-setting="strong_testimonials_alt_server"
								id="strong_testimonials_alt_server"
								name="strong_testimonials_alt_server"
								value="1" <?php checked( $alt_server, 'true', 'false' ); ?>>
							<div class="wpmtst-toggle__items">
								<span class="wpmtst-toggle__track"></span>
								<span class="wpmtst-toggle__thumb"></span>
								<svg class="wpmtst-toggle__off" width="6" height="6" aria-hidden="true" role="img"
									focusable="false" viewBox="0 0 6 6">
									<path d="M3 1.5c.8 0 1.5.7 1.5 1.5S3.8 4.5 3 4.5 1.5 3.8 1.5 3 2.2 1.5 3 1.5M3 0C1.3 0 0 1.3 0 3s1.3 3 3 3 3-1.3 3-3-1.3-3-3-3z"></path>
								</svg>
								<svg class="wpmtst-toggle__on" width="2" height="6" aria-hidden="true" role="img"
									focusable="false" viewBox="0 0 2 6">
									<path d="M0 0h2v6H0z"></path>
								</svg>
							</div>
						</div>
						<p class="description">
							<?php esc_html_e( 'Sometimes there can be problems with the activation server, in which case please try the alternative one.', 'strong-testimonials-pro' ); ?>
						</p>
					</fieldset>
				</td>
			</tr>
			<tr valign="top">
				<th scope="row">
					<?php esc_html_e( 'Action', 'strong-testimonials-pro' ); ?>
				</th>
				<td>
				<button class="button button-primary" id="st-master-license-btn" data-action="<?php echo ( ! $valid_license ) ? 'activate' : 'deactivate'; ?>"><?php ( ! $valid_license ) ? esc_html_e( 'Activate', 'strong-testimonials-pro' ) : esc_html_e( 'Deactivate', 'strong-testimonials-pro' ); ?></button>
				</td>
			</tr>

		</table>


		<?php
	}

	/**
	 * License tab name.
	 *
	 * @param string $name The name.
	 *
	 * @return string
	 * @since 1.1.0
	 */
	public function license_tab_name( $name, $active_tab, $url ) {
		return sprintf(
			'<a href="%1$s" class="nav-tab %2$s">%3$s</a>',
			esc_url( add_query_arg( 'tab', 'license', $url ) ),
			esc_attr( 'license' === $active_tab ? 'nav-tab-active' : '' ),
			esc_html__( 'License', 'strong-testimonials-pro' ),
		);
	}
}

Strong_Testimonials_Pro_License::get_instance();
