<?php

if ( ! class_exists( 'Strong_Testimonials_License_Activator' ) ) {

	class Strong_Testimonials_License_Activator {

		private $main_item_name = 'Strong Testimonials';
		private $main_item_id   = 13054; // the download id of this addon

		public function __construct() {
			add_action( 'admin_init', array( $this, 'register_license_option' ) );
			add_action( 'admin_init', array( $this, 'activate_license' ) );
			add_action( 'admin_init', array( $this, 'deactivate_license' ) );
			add_action( 'wpmtst_license_errors', array( $this, 'admin_notices' ) );
		}

		public function activate_license() {

			// listen for our activate button to be clicked
			if ( isset( $_POST['strong_testimonials_license_activate'] ) ) {

				// run a quick security check
				if ( ! check_admin_referer( 'strong_testimonials_license_nonce', 'strong_testimonials_license_nonce' ) ) {
					return;
				}

				// retrieve the license from the database
				$license = trim( get_option( 'strong_testimonials_license_key' ) );

				// data to send in our API request
				$api_params = array(
					'edd_action' => 'activate_license',
					'license'    => $license,
					'item_id'    => $this->main_item_id,
					'url'        => home_url(),
				);

				// Call the custom API.
				$response = wp_remote_post(
					WPMTST_STORE_URL,
					array(
						'timeout'   => 15,
						'sslverify' => false,
						'body'      => $api_params,
					)
				);

				// make sure the response came back okay
				if ( is_wp_error( $response ) || 200 !== wp_remote_retrieve_response_code( $response ) ) {
					if ( is_wp_error( $response ) ) {
						$message = $response->get_error_message();
					} else {
						$message = __( 'An error occurred, please try again.', 'strong-testimonials-pro' );
					}
				} else {
					$license_data = json_decode( wp_remote_retrieve_body( $response ) );
					if ( false === $license_data->success ) {
						switch ( $license_data->error ) {
							case 'expired':
								$message = sprintf(
									/* translators: %s: The expiration date of the license. */
									__( 'Your license key expired on %s.', 'strong-testimonials-pro' ),
									date_i18n( get_option( 'date_format' ), strtotime( $license_data->expires, current_time( 'timestamp' ) ) ) //phpcs:ignore WordPress.DateTime.CurrentTimeTimestamp.Requested
								);
								break;
							case 'disabled':
							case 'revoked':
								$message = __( 'Your license key has been disabled.', 'strong-testimonials-pro' );
								break;
							case 'missing':
								$message = __( 'Invalid license.', 'strong-testimonials-pro' );
								break;
							case 'invalid':
							case 'site_inactive':
								$message = __( 'Your license is not active for this URL.', 'strong-testimonials-pro' );
								break;
							case 'item_name_mismatch':
								/* translators: %s: The name of the plugin.*/
								$message = sprintf( __( 'This appears to be an invalid license key for %s.', 'strong-testimonials-pro' ), $this->main_item_name );
								break;
							case 'no_activations_left':
								$message = __( 'Your license key has reached its activation limit.', 'strong-testimonials-pro' );
								break;
							default:
								$message = __( 'An error occurred, please try again.', 'strong-testimonials-pro' );
								break;
						}
					}
				}

				// Check if anything passed on a message constituting a failure
				if ( ! empty( $message ) ) {
					$base_url = admin_url( 'edit.php?post_type=wpm-testimonial&page=testimonial-settings&tab=licenses' );
					$redirect = add_query_arg(
						array(
							'sl_activation' => 'false',
							'message'       => urlencode( $message ),
						),
						$base_url
					);
					wp_redirect( $redirect );
					exit();
				}

				// $license_data->license will be either "valid" or "invalid"
				update_option( 'strong_testimonials_license_status', $license_data );
				wp_redirect( admin_url( 'edit.php?post_type=wpm-testimonial&page=testimonial-settings&tab=licenses' ) );
				exit();
			}
		}
		public function deactivate_license() {

			// listen for our deactivate button to be clicked
			if ( isset( $_POST['strong_testimonials_license_deactivate'] ) ) {
				// run a quick security check
				if ( ! check_admin_referer( 'strong_testimonials_license_nonce', 'strong_testimonials_license_nonce' ) ) {
					return; // get out if we didn't click the Activate button
				}

				// retrieve the license from the database
				$license = trim( get_option( 'strong_testimonials_license_key' ) );

				// data to send in our API request
				$api_params = array(
					'edd_action' => 'deactivate_license',
					'license'    => $license,
					'item_id'    => $this->main_item_id,
					'url'        => home_url(),
				);

				// Call the custom API.
				$response = wp_remote_post(
					WPMTST_STORE_URL,
					array(
						'timeout'   => 15,
						'sslverify' => false,
						'body'      => $api_params,
					)
				);

				// make sure the response came back okay
				if ( is_wp_error( $response ) || 200 !== wp_remote_retrieve_response_code( $response ) ) {
					if ( is_wp_error( $response ) ) {
						$message = $response->get_error_message();
					} else {
						$message = __( 'An error occurred, please try again.', 'strong-testimonials-pro' );
					}
					$base_url = admin_url( 'edit.php?post_type=wpm-testimonial&page=testimonial-settings&tab=licenses' );
					$redirect = add_query_arg(
						array(
							'sl_activation' => 'false',
							'message'       => urlencode( $message ),
						),
						$base_url
					);
					wp_redirect( $redirect );
					exit();
				}

				// decode the license data
				$license_data = json_decode( wp_remote_retrieve_body( $response ) );

				// $license_data->license will be either "deactivated" or "failed"
				if ( 'deactivated' === $license_data->license ) {
					delete_option( 'strong_testimonials_license_status' );
				}

				wp_redirect( admin_url( 'edit.php?post_type=wpm-testimonial&page=testimonial-settings&tab=licenses' ) );
				exit();
			}
		}

		public function register_license_option() {
			// creates our settings in the options table
			register_setting( 'strong_testimonials_license_key', 'strong_testimonials_license_key', array( $this, 'sanitize_license' ) );
		}

		public function sanitize_license( $new_license ) {
			$old_license = get_option( 'strong_testimonials_license_key' );
			if ( $old_license && $old_license !== $new_license ) {
				delete_option( 'strong_testimonials_license_status' ); // new license has been entered, so must reactivate
				delete_transient( 'strong_testimonials_licensed_extensions' );
			}
			return $new_license;
		}

		public function admin_notices() {
			if ( isset( $_GET['sl_activation'] ) && ! empty( $_GET['message'] ) ) {
				switch ( $_GET['sl_activation'] ) {
					case 'false':
						$message = urldecode( $_GET['message'] );
						?>
						<div class="error">
							<p><?php echo esc_html( $message ); ?></p>
						</div>
						<?php
						break;
					case 'true':
					default:
						// Developers can put a custom success message here for when activation is successful if they way.
						break;
				}
			}
		}
	}

	new Strong_Testimonials_License_Activator();

}
