<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


/**
 * Class Strong_Testimonials_Pro_Admin
 */
class Strong_Testimonials_Pro_Admin {


	public function __construct() {

		// $this->includes();

		$this->add_actions();
	}

	public function add_actions() {

		add_action( 'admin_init', array( $this, 'register_admin_scripts' ) );
		add_action( 'admin_enqueue_scripts', array( $this, 'enqueue_admin_scripts' ) );

		// List table columns
		add_action( 'admin_init', array( $this, 'init' ) );

		// Add tag select list option after title
		add_action( 'wpmtst_view_editor_after_group_fields_title', array( $this, 'view_editor_title_tags' ) );
		// Sanitize new options
		add_filter( 'wpmtst_sanitized_view', array( $this, 'sanitize_view' ), 10, 2 );

		// Submit buttons
		add_action( 'wpmtst_settings_submit_row', array( $this, 'submit_buttons' ) );

		// Admin notices
		add_filter( 'wpmtst_admin_notice', array( $this, 'admin_notice' ), 10, 2 );

		// Admin search
		add_filter( 'posts_join', array( $this, 'wpmtst_search_join' ) );
		add_filter( 'posts_where', array( $this, 'wpmtst_search_where' ) );
		add_filter( 'posts_distinct', array( $this, 'wpmtst_search_distinct' ) );

		// Alter title markup
		add_filter( 'wpmtst_the_title_tag', array( $this, 'wpmtst_alter_tag' ) );

		// Sanitize options
		add_filter( 'wpmtst_sanitize_form_options', array( $this, 'sanitize_options' ) );

		// Single Template Style
		add_action( 'init', array( $this, 'single_testimonial_template' ) );
		add_action( 'admin_init', array( $this, 'wpmtst_update_check' ), 5 );
		register_activation_hook( __FILE__, array( $this, 'wpmtst_setup_style_options_custom_fields' ) );

		// Remove single template mode
		add_filter( 'wpmtst_mode_description', array( $this, 'wpmtst_mode_description' ), 10, 2 );
		add_filter( 'wpmtst_views_query_results', array( $this, 'wpmtst_list_views' ) );
		// Add default avatar and initials image settings
		add_action( 'wpmtst_avatar_options', array( $this, 'wpmtst_avatar_options' ) );
		// Add default image file upload button in view
		add_action( 'after_no_featured_image', array( $this, 'after_no_featured_image' ) );
		// Add new options oto view default image
		add_filter( 'wpmtst_thumbnail_default_img', array( $this, 'wpmtst_thumbnail_default_img' ), 10, 3 );
		add_action(
			'admin_enqueue_scripts',
			function () {
				wp_enqueue_media();
			}
		);
		// Prefill testimonial form
		add_filter( 'get_predefined_values', array( $this, 'get_predefined_values' ), 10, 2 );

		// Add members only setting to form
		add_action( 'wpmtst_before_form_actions', array( $this, 'members_only_form_settings' ) );
	}


	public function init() {
	}

	// public function includes() {
	//  require_once WPMTST_PRO_PATH . 'admin/functions.php';
	// }

	public static function register_admin_scripts() {
		wp_register_script( 'wpmtst-pro-admin-js', WPMTST_PRO_URL . 'assets/js/admin.js', array( 'jquery' ), false );
	}

	public static function enqueue_admin_scripts() {
		wp_enqueue_script( 'wpmtst-pro-admin-js' );
				wp_enqueue_style( 'wp-color-picker' );
	}

	public static function get_defaults() {
		$defaults = array(
			'title_tag' => 'h3',
		);
		return $defaults;
	}

	public function submit_buttons() {
		// TODO Refactor this; i.e. if can_undo_changes( $tab )
		if ( isset( $_GET['tab'] ) && 'strong-testimonials-pro' === $_GET['tab'] ) {
			$sections = array( 'fields', 'troubleshooting' );
			if ( isset( $_GET['section'] ) && in_array( $_GET['section'], $sections, true ) ) {
				submit_button( '', 'primary', 'submit-form', false );
				printf( '<input type="reset" id="reset" class="button" value="%s"/>', esc_html__( 'Undo Changes', 'strong-testimonials-pro' ) );
			}
		}
	}

	public static function get_filters() {

		$cat_count = get_terms( 'wpm-testimonial-category', array( 'hide_empty' => true ) );
		$filters[] = array(
			'name' => 'all',
			'slug' => '*',
		);
		foreach ( $cat_count as $value ) {
			$filters[] = array(
				'name' => $value->name,
				'slug' => 'wpmtst-' . $value->slug,
			);

		}
		return $filters;
	}

	/**
	 * Filter to sanitize View elements.
	 *
	 * @param $view_data
	 * @param $input
	 *
	 * @return mixed
	 */
	public function sanitize_view( $view_data, $input ) {
		$view_data['title_tag']           = isset( $input['title_tag'] ) ? sanitize_text_field( $input['title_tag'] ) : '';
		$view_data['avatar']              = isset( $input['avatar'] ) ? sanitize_text_field( $input['avatar'] ) : '';
		$view_data['initials_font_size']  = isset( $input['initials_font_size'] ) ? sanitize_text_field( $input['initials_font_size'] ) : '';
		$view_data['initials_font_color'] = isset( $input['initials_font_color'] ) ? sanitize_text_field( $input['initials_font_color'] ) : '';
		$view_data['initials_bg_color']   = isset( $input['initials_bg_color'] ) ? sanitize_text_field( $input['initials_bg_color'] ) : '';
		$view_data['default_image']       = isset( $input['saved_image'] ) ? sanitize_text_field( $input['saved_image'] ) : '';
		$view_data['saved_image']         = $view_data['default_image'];

		return $view_data;
	}

	/**
	 * Admin notices.
	 *
	 * @param $html
	 * @param $key
	 *
	 * @return string
	 * @since 1.0.0
	 */
	public function admin_notice( $html = '', $key = '' ) {
		$settings_url = admin_url( 'edit.php?post_type=wpm-testimonial&page=testimonial-settings&tab=strong-testimonials-pro' );
		/* translators: %s: The settings URL. */
		$settings_link = sprintf( wp_kses( __( '<a href="%s">Go to settings</a>', 'strong-testimonials-pro' ), array( 'a' => array( 'href' => array() ) ) ), esc_url( $settings_url ) );

		switch ( $key ) {

			case 'strong-testimonials-pro_mismatch':
				ob_start();
				?>
				<div class="wpmtst notice notice-error is-dismissible" data-error="strong-testimonials-pro_mismatch">
					<p>
						<?php esc_html__( 'Configuration error in <strong>Strong Testimonials Pro</strong>.', 'strong-testimonials-pro' ); ?>
						<?php echo esc_url( $settings_link ); ?>
					</p>
				</div>
				<?php
				$html = ob_get_clean();
				break;

			default:
				// nothing
		}

		return $html;
	}

	public function filters_after_testimonial( $atts ) {

		if ( $atts ) {
			if ( isset( $atts['st_pro_filters'] ) && 1 === (int) $atts['st_pro_filters'] && 'display' === $atts['mode'] && 0 === $atts['pagination'] ) :
				?>
					</div> 
				<?php
				endif;
		}
	}

	public function wpmtst_search_join( $join ) {
		global $wpdb;

		if ( is_search() && get_query_var( 'post_type' ) === 'wpm-testimonial' ) {
			$join .= ' LEFT JOIN ' . $wpdb->postmeta . ' ON ' . $wpdb->posts . '.ID = ' . $wpdb->postmeta . '.post_id ';
		}

		return $join;
	}

	public function wpmtst_search_where( $where ) {
		global $wpdb;

		if ( is_search() && get_query_var( 'post_type' ) === 'wpm-testimonial' ) {
			$where = preg_replace(
				'/\(\s*' . $wpdb->posts . ".post_title\s+LIKE\s*(\'[^\']+\')\s*\)/",
				'(' . $wpdb->posts . '.post_title LIKE $1) OR (' . $wpdb->postmeta . '.meta_value LIKE $1)',
				$where
			);
		}

		return $where;
	}

	public function wpmtst_search_distinct( $where ) {
		if ( is_search() && get_query_var( 'post_type' ) === 'wpm-testimonial' ) {
			return 'DISTINCT';
		}

		return $where;
	}

	public function wpmtst_alter_tag( $tag ) {
		$tag = WPMST()->atts( 'title_tag' );
		if ( isset( $tag ) && ! empty( $tag ) ) {
			return $tag;
		}
		return 'h3';
	}

	public function view_editor_title_tags() {
		include WPMTST_PRO_PATH . 'admin/views/option-title-tag.php';
	}

		/**
	 * Sanitize settings.
	 *
	 * @param $input
	 *
	 * @return array
	 */
	public static function sanitize_options( $input ) {
			$input['members_only']         = wpmtst_sanitize_checkbox( $input, 'members_only' );
			$input['members_only_message'] = sanitize_text_field( $input['members_only_message'] );

			return $input;
	}

	public function single_testimonial_template() {
		include WPMTST_PRO_PATH . 'admin/settings/class-strong-testimonials-settings-single-testimonial.php';
	}

	/**
	* Check for plugin update.
	*
	*/
	public function wpmtst_update_check() {
		$version = get_option( 'wpmtst_pro_plugin_version', false );
		if ( WPMTST_PRO_VERSION === $version ) {
				return;
		}
			Strong_Testimonials_Pro_Updater::update();
	}

	/**
	* Add avatar default image, author initials and WordPress avatar options.
	*
	*/
	public function wpmtst_avatar_options( $view ) {

		?>
		<option value="default" <?php selected( $view['gravatar'], 'default' ); ?>><?php _e( 'show default image', 'strong-testimonials' ); ?></option>
		<option value="initials" <?php selected( $view['gravatar'], 'initials' ); ?>><?php _e( 'show author initials', 'strong-testimonials' ); ?></option>
		<option value="wp_avatars" <?php selected( $view['gravatar'], 'wp_avatars' ); ?>><?php _e( 'show custom avatars', 'strong-testimonials' ); ?></option>
		<?php
	}

	public function after_no_featured_image( $view ) {
		$saved_image = '';
		if ( isset( $view['saved_image'] ) && ! empty( $view['saved_image'] ) ) {
			$saved_image = $view['saved_image'];
		}
		?>
		<div class="then fast then_default then_not_no then_not_if then_not_yes then_not_initials then_not_wp_avatars wpmtst_default_preview_image" style="display: none;">
			<?php if ( isset( $view['saved_image'] ) ) : ?>
				<?php $image_url = wp_get_attachment_url( $view['saved_image'] ); ?>
				<img class="wpmtst_default_processed_image" width="100" src="<?php echo $image_url; ?>" ><br />
				<a class="wpmtst_default_remove_image" href="#"><?php _e( 'Remove image' ); ?></a>
			<?php endif; ?>
		</div>
		<div class="then fast then_default then_not_no then_not_if then_not_yes then_not_initials then_not_wp_avatars" style="display: none;">
			<label for="view-gravatar">
					<?php _e( 'Default Image', 'strong-testimonials' ); ?>
			</label>
			<input type="number" value="<?php echo $saved_image; ?>" class="regular-text process_custom_images" id="process_custom_images" name="view[data][saved_image]" style="display:none">
			<button class="set_default_image button"><?php _e( 'Select Image' ); ?></button>
		</div>
		<div>
			<div class="then fast then_not_default then_not_no then_not_if then_not_yes then_initials then_not_wp_avatars" style="display: none;">
				<label for="initials_font_size"> <?php _e( 'Font size', 'strong-testimonials' ); ?></label><br />
				<input type="number" name="view[data][initials_font_size]" value="<?php echo $view['initials_font_size']; ?>" min="1" class="input-incremental"><span> px</span><br />
				<label for="initials_font_color"> <?php _e( 'Font color', 'strong-testimonials' ); ?></label><br />
				<input type="text" id="initials-font-color" name="view[data][initials_font_color]" value="<?php echo $view['initials_font_color']; ?>" class="wp-color-picker-field"><br />
				<label for="initials_bg_color"> <?php _e( 'Background color', 'strong-testimonials' ); ?></label><br />
				<input type="text" id="initials-bg-color" name="view[data][initials_bg_color]" value="<?php echo $view['initials_bg_color']; ?>" class="wp-color-picker-field">
			</div>
		</div>
		<div>
			<div class="then fast then_wp_avatars then_not_default then_not_no then_not_if then_not_yes then_not_initials" style="display: none;">
				<?php $this->wpmtst_wp_avatars( $view ); ?>
			</div>
		</div>
		<?php
	}

	public function wpmtst_wp_avatars( $view ) {
		$default = 'mystery';
		if ( isset( $view['avatar'] ) && ! empty( $view['avatar'] ) ) {
			$default = $view['avatar'];
		}
		$avatar_defaults = array(
			'mystery'          => __( 'Mystery Person' ),
			'blank'            => __( 'Blank' ),
			'gravatar_default' => __( 'Gravatar Logo' ),
			'identicon'        => __( 'Identicon (Generated)' ),
			'wavatar'          => __( 'Wavatar (Generated)' ),
			'monsterid'        => __( 'MonsterID (Generated)' ),
			'retro'            => __( 'Retro (Generated)' ),
		);
		$avatar_list     = '';
		foreach ( $avatar_defaults as $default_key => $default_name ) {
			$selected     = ( $default === $default_key ) ? 'checked="checked" ' : '';
			$avatar_list .= "\n\t<label><input type='radio' name='view[data][avatar]' id='avatar_{$default_key}' value='" . esc_attr( $default_key ) . "' {$selected}/> ";
			$avatar_list .= get_avatar( 0, 32, $default_key, '', array( 'force_default' => true ) );
			$avatar_list .= ' ' . $default_name . '</label>';
			$avatar_list .= '<br />';
		}

		remove_filter( 'pre_option_show_avatars', '__return_true', 100 );
		echo apply_filters( 'default_avatar_select', $avatar_list );
	}

	/**
	* Remove Single Template from views if PRO is active.
	*
	*/

	public function wpmtst_mode_description( $description, $mode ) {
		if ( 'single_template' === $mode ) {
			return 'Single Template settings have been permanently moved to the <a target="_blank" href="/wp-admin/edit.php?post_type=wpm-testimonial&page=testimonial-settings&tab=single_testiomonial_template">Settings section</a>. This option will be removed in the future.';
		}
		return $description;
	}

	//removing Single Template from query results if PRO is active.
	public function wpmtst_list_views( $data ) {
		foreach ( $data as $key => $item ) {
			$item = unserialize( $item['value'] );
			if ( 'single_template' === $item['mode'] ) {
				unset( $data[ $key ] );
			}
		}
		return $data;
	}

	public function wpmtst_thumbnail_default_img( $img, $id, $size ) {

		if ( 'default' === WPMST()->atts( 'gravatar' ) ) {
			if ( WPMST()->atts( 'default_image' ) ) {
					$img = wp_get_attachment_image( WPMST()->atts( 'default_image' ), $size );
			}
		} elseif ( 'initials' === WPMST()->atts( 'gravatar' ) ) {
				$client_name = get_post_meta( $id, 'client_name' );
				$width       = intval( get_option( "{$size}_size_w" ) );
				$height      = intval( get_option( "{$size}_size_h" ) );
			if ( isset( $client_name[0] ) && ! empty( $client_name[0] ) ) {
				wp_register_style( 'initials-inline-css', false );
				wp_enqueue_style( 'initials-inline-css' );
				$view_el = '.strong-view-id-' . WPMST()->atts( 'view' );
				wp_add_inline_style(
					'initials-inline-css',
					'body ' . $view_el . ' .wpmtst-testimonial-inner .wpmtst-testimonial-image .initials {
                            background-color: ' . WPMST()->atts( 'initials_bg_color' ) . ';
                            color: ' . WPMST()->atts( 'initials_font_color' ) . ';
                            font-size: ' . WPMST()->atts( 'initials_font_size' ) . 'px;
                    }'
				);
				$words = explode( ' ', $client_name[0] );
				$img   = '<div style="width:' . $width . 'px; height:' . $height . 'px" class="initials">' . strtoupper( substr( $words[0], 0, 1 ) . substr( end( $words ), 0, 1 ) ) . '</div>';
			}
		} elseif ( 'wp_avatars' === WPMST()->atts( 'gravatar' ) ) {
				$size = intval( get_option( "{$size}_size_w" ) );
			if ( WPMST()->atts( 'avatar' ) ) {
				$img = get_avatar( 0, $size, WPMST()->atts( 'avatar' ), '', array( 'force_default' => true ) );
			}
		}

		if ( WPMST()->atts( 'lightbox' ) ) {
			$url = wp_get_attachment_url( WPMST()->atts( 'default_image' ) );
			if ( $url ) {
				$class_array = array( WPMST()->atts( 'lightbox_class' ) );
				$classes     = implode( ' ', array_unique( apply_filters( 'wpmtst_thumbnail_link_class', $class_array ) ) );
				$img         = sprintf( '<a class="%s" href="%s">%s</a>', $classes, esc_url( $url ), $img );
			}
		}
		return $img;
	}

	/**
	 * Return form values. Prefill testimonial form.
	 *
	 * @return mixed
	 */
	public function get_predefined_values( $form_values, $field ) {
		foreach ( $form_values as $name => $value ) {
			if ( isset( $_GET[ $name ] ) && ! empty( $_GET[ $name ] ) ) {
				switch ( $field['input_type'] ) {
					case 'checkbox':
						$form_values[ $name ] = (bool) $_GET[ $name ];
						break;
					case 'rating':
						$form_values[ $name ] = (int) $_GET[ $name ];
						break;
					default:
						$form_values[ $name ] = $_GET[ $name ];
				}
			}
		}
		return $form_values;
	}

	public function members_only_form_settings( $form_options ) {
		if ( isset( $form_options['source'] ) ) {
			// DO NOTHING
		} else {
			$form_options['source'] = 'wpmtst_form_options';
		}
		?>
		<tr>
		<th scope="row" class="tall">
						<?php esc_html_e( 'Members only', 'strong-testimonials' ); ?>
		</th>
		<td>
			<fieldset>
				<div>
					<label>
						<input type="checkbox"
								name="<?php echo $form_options['source']; ?>[members_only]" <?php ( isset( $form_options['members_only'] ) ? checked( $form_options['members_only'] ) : '' ); ?>/>
										<?php printf( __( 'Only logged in users can fill in a testimonial form. Off by default', 'strong-testimonials' ) ); ?>
				</div>
			</fieldset>
		</td>
	</tr>
	<tr>
		<th scope="row" class="tall">
						<?php esc_html_e( 'Restricted notice', 'strong-testimonials' ); ?>
		</th>
		<td>
			<input type="text" name="<?php echo $form_options['source']; ?>[members_only_message]" value="<?php echo ( isset( $form_options['members_only_message'] ) ? esc_attr( $form_options['members_only_message'] ) : '' ); ?>" style="width:100%" />
		</td>
	</tr> 
		<?php
	}
}
