<?php

$license = get_option( 'strong_testimonials_license_key' );
$status  = get_option( 'strong_testimonials_license_status', false );

$messages = array(
	'no-license'       => esc_html__( 'Enter your license key', 'strong-testimonials-pro' ),
	'activate-license' => esc_html__( 'Activate your license key', 'strong-testimonials-pro' ),
	/* translators: %s: The expiration date of the license. */
	'all-good'         => __( 'Your license is active until <strong>%s</strong>', 'strong-testimonials-pro' ),
	'lifetime'         => __( 'You have a lifetime license.', 'strong-testimonials-pro' ),
	'expired'          => esc_html__( 'Your license has expired', 'strong-testimonials-pro' ),
);

if ( '' === $license ) {
	$license_message = $messages['no-license'];
} elseif ( '' !== $license && false === $status ) {
	$license_message = $messages['activate-license'];
} elseif ( 'expired' === $status->license ) {
	$license_message = $messages['expired'];
} elseif ( '' !== $license && false !== $status && isset( $status->license ) && 'valid' === $status->license ) {

	$date_format = get_option( 'date_format' );

	if ( 'lifetime' === $status->expires ) {
		$license_message = $messages['lifetime'];
	} else {
		$license_expire = date( $date_format, strtotime( $status->expires ) ); // phpcs:ignore WordPress.DateTime.RestrictedFunctions.date_date
		$curr_time      = time();
		// weeks till expiration
		$weeks = (int) ( ( strtotime( $status->expires ) - $curr_time ) / ( 7 * 24 * 60 * 60 ) );

		// set license status based on colors
		if ( 4 >= $weeks ) {
			$l_stat = 'red';
		} else {
			$l_stat = 'green';
		}

		$license_message = sprintf( '<p class="%s">' . $messages['all-good'] . '</p>', $l_stat, $license_expire );

		if ( 'green' !== $l_stat ) {
			/* translators: %s: The number of weeks untill the license expires. */
			$license_message .= sprintf( __( 'You have %s week(s) untill your license will expire.', 'strong-testimonials-pro' ), $weeks );
		}
	}
}

?>
<div class="row">
	<?php do_action( 'wpmtst_license_errors' ); ?>
	<table class="form-table">
		<tbody>
			<tr valign="top">
				<th scope="row" valign="top">
					<?php esc_html_e( 'License Key', 'strong-testimonials-pro' ); ?>
				</th>
				<td>
					<input id="strong_testimonials_license_key" name="strong_testimonials_license_key" type="password" class="regular-text" value="<?php echo esc_attr( $license ); ?>" />
					<?php
					if ( '' !== $license && $status && ( 'expired' === $status->license || ( isset( $l_stat ) && 'green' !== $l_stat ) ) ) {
						echo '<a href="' . esc_url( WPMTST_STORE_URL ) . '/checkout/?edd_action=apply_license_renewal&edd_license_key=' . $license . '" class="button button-primary" target="_blank">Renew license</a>';
					}
					?>

					<label class="description strong-testimonials-license-label" for="strong_testimonials_license_key">
						<?php
						echo wp_kses_post( $license_message );
						?>
					</label>
				</td>
			</tr>
			<?php if ( false !== $license ) : ?>
				<tr valign="top">
					<th scope="row" valign="top">
						<?php esc_html_e( 'Activate License', 'strong-testimonials-pro' ); ?>
					</th>
					<td>
						<?php if ( false !== $status && isset( $status->license ) && 'valid' === $status->license ) { ?>
							<?php wp_nonce_field( 'strong_testimonials_license_nonce', 'strong_testimonials_license_nonce' ); ?>
							<input type="submit" class="button-secondary" name="strong_testimonials_license_deactivate" value="<?php esc_attr_e( 'Deactivate License', 'strong-testimonials-pro' ); ?>"/>
						<?php } else { ?>
							<?php wp_nonce_field( 'strong_testimonials_license_nonce', 'strong_testimonials_license_nonce' ); ?>
							<input type="submit" class="button-secondary" name="strong_testimonials_license_activate" value="<?php esc_attr_e( 'Activate License', 'strong-testimonials-pro' ); ?>"/>
						<?php } ?>
					</td>
				</tr>
			<?php endif; ?>
		</tbody>
	</table>
</div>
