<?php
/**
 * Plugin Name: Strong Testimonials Pro
 * Plugin URI: https://strongplugins.com/plugins/strong-testimonials
 * Description: PRO Version of Strong Testimonials
 * Author: WPChill
 * Version: 1.1.2.1
 * Text Domain: strong-testimonials-pro
 * Domain Path: /languages
 * Requires: 4.0 or higher
 * License: GPLv3 or later
 * License URI: http://www.gnu.org/licenses/gpl-3.0.html
 * Requires PHP: 5.6
 *
 * Copyright 2020 MachoThemes office@machothemes.com
 *
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}




add_filter('pre_http_request', function ($pre, $parsed_args, $url) {
	
	if (strpos($url, 'https://strongtestimonials.com') !== false || strpos($url, 'https://license.wpchill.com/strongtestimonials') !== false) {


		if(isset($parsed_args['body']['edd_action']) &&  $parsed_args['body']['edd_action'] == 'deactivate_license' ){
			$license = 'deactivated';
		}else{
			$license = 'valid';
		}

		return [
			'response' => ['code' => 200, 'message' => 'ОК'],
			'body'     => json_encode(['success' => true, 'license' => $license, 'expires' => 'lifetime'])
		];
	}

	//'license' => deactivated

	return $pre;
}, 1, 3);


defined( 'WPMTST_PRO_VERSION' ) || define( 'WPMTST_PRO_VERSION', '1.1.2' );

/**
 * Check for minimum required versions
 */
if ( ! version_compare( PHP_VERSION, '5.3', '>=' ) ) {
	add_action( 'admin_notices', 'wpmtst_pro_fail_php_version' );
} elseif ( ! version_compare( get_bloginfo( 'version' ), '4.4', '>=' ) ) {
	add_action( 'admin_notices', 'wpmtst_pro_fail_wp_version' );
} elseif ( ! version_compare( get_option( 'wpmtst_plugin_version' ), '2.3', '>=' ) ) {
	add_action( 'admin_notices', 'wpmtst_pro_fail_plugin_version' );
} else {
	add_action( 'plugins_loaded', 'wpmtst_pro_run' );
}

/**
 * Fire it up.
 */
function wpmtst_pro_run() {
	if ( ! class_exists( 'Strong_Testimonials' ) ) {
		add_action( 'admin_notices', 'wpmtst_pro_require_lite_plugin' );
		return;
	}

	if ( ! class_exists( 'Strong_Testimonials_Pro' ) ) {
		require_once plugin_dir_path( __FILE__ ) . 'class-strong-testimonials-pro.php';
	}

	global $strong_pro;
	$strong_pro = new Strong_Testimonials_Pro();
}

/**
 * ST PRO admin notice for minimum PHP version.
 *
 * Warning when the site doesn't have the minimum required PHP version.
 *
 * @since 1.6.0
 */
function wpmtst_pro_fail_php_version() {
	/* translators: %s: PHP version */
	$message      = sprintf( esc_html__( 'Strong Testimonials Pro requires PHP version %s+. The plugin is currently ACTIVE but functionality NOT applied.', 'strong-testimonials-pro' ), '5.3' );
	$html_message = sprintf( '<div class="error">%s</div>', wpautop( $message ) );
	echo wp_kses_post( $html_message );
}

/**
 * ST Pro admin notice for minimum WordPress version.
 *
 * Warning when the site doesn't have the minimum required WordPress version.
 *
 * @since 1.6.0
 */
function wpmtst_pro_fail_wp_version() {
	/* translators: %s: WordPress version */
	$message      = sprintf( esc_html__( 'Strong Testimonials Pro requires WordPress version %s+. The plugin is currently ACTIVE but functionality NOT applied.', 'strong-testimonials-pro' ), '4.4' );
	$html_message = sprintf( '<div class="error">%s</div>', wpautop( $message ) );
	echo wp_kses_post( $html_message );
}


/**
 * ST Pro admin notice for Strong Testimonials Lite requirement.
 *
 * @since 1.0.11
 */
function wpmtst_pro_require_lite_plugin() {
	/* translators: %s: WordPress version */
	$message      = __( 'Strong Testimonials Pro requires Strong Testimonials Lite plugin to be installed and active. The plugin is currently ACTIVE but functionality is NOT applied.', 'strong-testimonials-pro' );
	$html_message = sprintf( '<div class="error">%s</div>', wpautop( $message ) );
	echo wp_kses_post( $html_message );
}

/**
 * ST PRO admin notice for minimum WordPress version.
 *
 * Warning when the site doesn't have the minimum required WordPress version.
 *
 * @since 1.6.0
 */
function wpmtst_pro_fail_plugin_version() {
	/* translators: %s: Strong Testimonials plugin version */
	$message      = sprintf( esc_html__( 'Strong Testimonials Pro requires Strong Testimonials version %s+. The plugin is currently ACTIVE but functionality NOT applied.', 'strong-testimonials-pro' ), '2.31' );
	$html_message = sprintf( '<div class="error">%s</div>', wpautop( $message ) );
	echo wp_kses_post( $html_message );
}

register_activation_hook( __FILE__, 'update_style_options_custom_fields' );
function update_style_options_custom_fields() {
	if ( ! class_exists( 'Strong_Testimonials' ) ) {
		deactivate_plugins( plugin_basename( __FILE__ ) );
		wp_die( __( 'Please install and activate Strong Testimonials before using Strong Testimonials PRO add-on.', 'strong-testimonials' ) );

	}
	$custom_fields = wpmtst_find_single_template_view();
	$options       = get_option( 'wpmtst_style_options', array() );
	// In case ['updated'] isn't defined is safe to assume that it's false
	if ( ! isset( $options['updated'] ) || ! $options['updated'] ) {
		$options['updated'] = true;
		// When you first install the plugin, $custom_fields might have the value "false" - we fallback to null as seen here ( /admin/settings/single-testimonial-template.php#L112 )
		$options['client_section'] = isset( $custom_fields['client_section'] ) ? $custom_fields['client_section'] : null;
		update_option( 'wpmtst_style_options', $options );
	}
}

register_activation_hook( __FILE__, 'wpmtst_pro_plugin_activation' );
register_deactivation_hook( __FILE__, 'wpmtst_pro_plugin_deactivation' );

/**
 * Plugin activation
 *
 * @since 1.0.8 Moved from Strong_Testimonials_Pro_Admin
 */
function wpmtst_pro_plugin_activation() {
	flush_rewrite_rules();
	require_once __DIR__ . '/includes/admin/class-strong-testimonials-pro-master-license-activator.php';
	if ( class_exists( 'Strong_Testimonials_Pro_Master_License_Activator' ) ) {
		$license = new Strong_Testimonials_Pro_Master_License_Activator();
		if ( method_exists( $license, 'get_installed_extensions' ) ) {
			$extensions = $license->get_installed_extensions();
			$extensions[] = 'strong-testimonials-pro';
			$license->force_license_activation( false, $extensions, 'activate-st' );
		}
	}
}

/**
 * Plugin deactivation
 *
 * @since 1.0.8 Moved from Strong_Testimonials_Pro_Admin
 */
function wpmtst_pro_plugin_deactivation() {
	flush_rewrite_rules();
	require_once __DIR__ . '/includes/admin/class-strong-testimonials-pro-master-license-activator.php';
	if ( class_exists( 'Strong_Testimonials_Pro_Master_License_Activator' ) ) {
		$license = new Strong_Testimonials_Pro_Master_License_Activator();
		if ( method_exists( $license, 'get_installed_extensions' ) ) {
			$extensions = $license->get_installed_extensions();
			$license->force_license_deactivation( false, $extensions, 'deactivate-st' );
		}
	}

	/**
	 * Unset stored version number to allow rollback and beta testing.
	 *
	 * @since 2.28.0
	 */
	delete_option( 'wpmtst_pro_plugin_version' );
}
